# PipelineSpecRuntimeConfig

The runtime config of a PipelineSpec.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**parameters** | [**dict(str, ProtobufValue)**](ProtobufValue.md) | The runtime parameters of the PipelineSpec. The parameters will be used to replace the placeholders at runtime. | [optional] 
**pipeline_root** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


